@@ -11,7 +11,7 @@
 #include "MoveEventHandler.hh"
 
 MoveEventHandler::MoveEventHandler(Config* cfg, PDecor* decor,
-                                   int x_root, int y_root)
+				   int x_root, int y_root)
 	: _cfg(cfg),
 	  _outline(!cfg->getOpaqueMove()),
 	  _show_status_window(cfg->isShowStatusWindow()),
@@ -24,6 +24,7 @@ MoveEventHandler::MoveEventHandler(Config* cfg, PDecor* decor,
 	decor->getGeometry(_last_gm);
 	_x = x_root - _gm.x;
 	_y = y_root - _gm.y;
+	_decor_shaded = decor->isShaded() ? _gm.height : 0;
 
 	pekwm::observerMapping()->addObserver(decor, this);
 }
@@ -36,8 +37,7 @@ MoveEventHandler::~MoveEventHandler(void)
 }
 
 void
-MoveEventHandler::notify(Observable *observable,
-                         Observation *observation)
+MoveEventHandler::notify(Observable *observable, Observation *observation)
 {
 	if (observation == &PWinObj::pwin_obj_deleted
 	    && observable == _decor) {
@@ -130,9 +130,10 @@ MoveEventHandler::handleMotionNotifyEvent(XMotionEvent *ev)
 		}
 	}
 
-	drawOutline();
 	updateStatusWindow(false);
 
+	drawOutline();
+
 	return EventHandler::EVENT_PROCESSED;
 }
 
@@ -157,7 +158,7 @@ void
 MoveEventHandler::drawOutline(void)
 {
 	if (_outline) {
-		_decor->drawOutline(_gm);
+		PDecor::drawOutline(_gm, _decor_shaded);
 	}
 }
 
@@ -202,15 +203,16 @@ void
 MoveEventHandler::doMoveEdgeAction(XMotionEvent *ev, EdgeType edge)
 {
 	uint button = X11::getButtonFromState(ev->state);
+	std::vector<ActionEvent> *edge_actions =
+		_cfg->getEdgeListFromPosition(edge);
 	ActionEvent *ae =
 		ActionHandler::findMouseAction(button, ev->state,
 					       MOUSE_EVENT_ENTER_MOVING,
-					       _cfg->getEdgeListFromPosition(edge));
+					       edge_actions);
 	if (ae) {
-		ActionPerformed ap(_decor, *ae);
+		ActionPerformedWithOffset ap(_decor, *ae, _x, _y);
 		ap.type = ev->type;
 		ap.event.motion = ev;
-
-		pekwm::actionHandler()->handleAction(ap);
+		pekwm::actionHandler()->handleAction(&ap);
 	}
 }
