@@ -1,5 +1,6 @@
 //
 // WorkspaceIndicator.cc for pekwm
+// Copyright (C) 2021-2022 Claes Nästén <pekdon@gmail.com>
 // Copyright (C) 2009-2020 the pekwm development team
 //
 // This program is licensed under the GNU GPL.
@@ -20,20 +21,16 @@
  * Display constructor
  */
 WorkspaceIndicator::Display::Display(PWinObj *parent)
-	: PWinObj(false),
-	  _pixmap(None)
+	: PWinObj(false)
 {
 	_parent = parent;
 	// Do not give the indicator focus, it doesn't handle input
 	_focusable = false;
 
-	XSetWindowAttributes attr;
-	attr.override_redirect = false;
-	attr.event_mask = ButtonPressMask|ButtonReleaseMask|ButtonMotionMask|
-		FocusChangeMask|KeyPressMask|KeyReleaseMask;
-	_window = X11::createWindow(_parent->getWindow(), 0, 0, 1, 1, 0,
-				    CopyFromParent, InputOutput, CopyFromParent,
-				    CWOverrideRedirect|CWEventMask, &attr);
+	long event_mask = ButtonPressMask|ButtonReleaseMask|ButtonMotionMask|
+			  FocusChangeMask|KeyPressMask|KeyReleaseMask;
+	_window = X11::createWmWindow(_parent->getWindow(), 0, 0, 1, 1,
+				      InputOutput, event_mask);
 }
 
 /**
@@ -42,7 +39,6 @@ WorkspaceIndicator::Display::Display(PWinObj *parent)
 WorkspaceIndicator::Display::~Display(void)
 {
 	X11::destroyWindow(_window);
-	X11::freePixmap(_pixmap);
 }
 
 /**
@@ -73,12 +69,12 @@ WorkspaceIndicator::Display::render(void)
 	Theme::WorkspaceIndicatorData *data =
 		pekwm::theme()->getWorkspaceIndicatorData();
 
-	// Make sure pixmap has correct size
-	X11::freePixmap(_pixmap);
-	_pixmap = X11::createPixmap(_gm.width, _gm.height);
+	// Make sure surface has correct size
+	_surface.resize(_gm.width, _gm.height);
 
 	// Render background
-	data->texture_background->render(_pixmap, 0, 0, _gm.width, _gm.height);
+	data->texture_background->render(&_surface,
+					 0, 0, _gm.width, _gm.height);
 
 	// Render workspace grid, then active workspace fill and end with
 	// rendering active workspace number and name
@@ -87,15 +83,17 @@ WorkspaceIndicator::Display::render(void)
 			 _gm.height - getPaddingVertical());
 
 	data->font->setColor(data->font_color);
-	data->font->draw(_pixmap,
+	data->font->draw(&_surface,
 			 data->edge_padding,
-			 _gm.height - data->edge_padding - data->font->getHeight(),
+			 _gm.height
+			     - data->edge_padding
+			     - data->font->getHeight(),
 			 Workspaces::getActWorkspace().getName(),
 			 0 /* max_chars */,
 			 _gm.width - data->edge_padding * 2 /* max_width */);
 
 	// Refresh
-	X11::setWindowBackgroundPixmap(_window, _pixmap);
+	X11::setWindowBackgroundPixmap(_window, _surface.getDrawable());
 	X11::clearWindow(_window);
 }
 
@@ -109,7 +107,7 @@ WorkspaceIndicator::Display::render(void)
  */
 void
 WorkspaceIndicator::Display::renderWorkspaces(int x, int y,
-                                              uint width, uint height)
+					      uint width, uint height)
 {
 	Theme::WorkspaceIndicatorData *data =
 		pekwm::theme()->getWorkspaceIndicatorData();
@@ -136,7 +134,7 @@ WorkspaceIndicator::Display::renderWorkspaces(int x, int y,
 
 		PTexture *tex = i == Workspaces::getActive()
 			? data->texture_workspace_act : data->texture_workspace;
-		tex->render(_pixmap, x_pos, y_pos, ws_width, ws_height);
+		tex->render(&_surface, x_pos, y_pos, ws_width, ws_height);
 
 		x_pos += ws_width + data->workspace_padding;
 	}
