@@ -263,7 +263,7 @@ PekwmPanel::PekwmPanel(const PanelConfig &cfg, PanelTheme &theme,
 			  static_cast<uint>(sh->width),
 			  static_cast<uint>(sh->height)),
 		 "", "panel", "pekwm_panel",
-		 WINDOW_TYPE_DOCK, sh),
+		 WINDOW_TYPE_DOCK, sh, true),
 	  _cfg(cfg),
 	  _theme(theme),
 	  _ext_data(cfg, _var_data),
@@ -277,7 +277,7 @@ PekwmPanel::PekwmPanel(const PanelConfig &cfg, PanelTheme &theme,
 			 PropertyChangeMask|SubstructureNotifyMask);
 
 	renderBackground();
-	X11::setWindowBackgroundPixmap(_window, _pixmap);
+	setBackground(_pixmap);
 
 	Atom state[] = {
 		X11::getAtom(STATE_STICKY),
@@ -319,6 +319,8 @@ PekwmPanel::configure(void)
 		pekwm::observerMapping()->addObserver(&_var_data, this);
 	}
 	resizeWidgets();
+
+	_wm_state.read();
 }
 
 void
@@ -564,7 +566,7 @@ PekwmPanel::renderPred(renderPredFun pred, void *opaque)
 
 	int x = handle ? handle->getWidth() : 0;
 	PanelWidget *last_widget = _widgets.back();
-	X11Render rend(_window);
+	X11Render rend(getRenderDrawable(), getRenderBackground());
 	std::vector<PanelWidget*>::iterator it = _widgets.begin();
 	for (; it != _widgets.end(); ++it) {
 		if (! (*it)->isVisible()) {
@@ -585,6 +587,8 @@ PekwmPanel::renderPred(renderPredFun pred, void *opaque)
 			x += sep->getWidth();
 		}
 	}
+
+	swapBuffer();
 }
 
 void
@@ -710,6 +714,7 @@ int main(int argc, char *argv[])
 	}
 	Util::expandFileName(config_file);
 	Util::expandFileName(_pekwm_config_file);
+	initEnvConfig(Util::getDir(_pekwm_config_file), _pekwm_config_file);
 
 	Display *dpy = XOpenDisplay(display);
 	if (! dpy) {
